//******************************************************************************
// The Humidity is monitored and once it goes over 40% the interrupt pin is on.
// THe application turn on the LDE 1 once the humidity is over the HUMIDITY_LIMIT. 
//
//
// Tested Platform: mini Controller Board PIC32
// Tested MCU: PIC32MX150F128D
// Tested Compiler: XC32 4.30
//******************************************************************************

#include "xc.h"

#define SYSTEM_CLOCK 32000000UL

#include "LTlib.h"

#include "HW_mini_Sensing_PIC_Board.h"

#include "LTlib_utilities.h"
#include "LTlib_utilities.c"

#include "module_IO.h"  
#include "module_IO.c" 

#include "module_UART.h"  
#include "module_UART.c" 

#include "module_I2C.h"
#include "module_I2C.c"

#include "LTlib_delay.h"
#include "LTlib_delay.c"

#include "HDC2080.h"
#include "HDC2080.c"

#define DEVICE_ADDRESS 0x40 //A0=GND
#define HUMIDITY_LIMIT 45


int main (void){

    uint8_t buffer[10];
    uint8_t counter = 0;
    
    float humidity = 0;
    float temperature = 0;
    uint16_t device_ID = 0;
           
    IO_set_all_ports_as_inputs ();
    delay_set_quartz(32);
    
    //Set LED as output
    LED_1_DIR = SET_AS_OUTPUT;
    LED_2_DIR = SET_AS_OUTPUT;
    
    HDC_INT_DIR = SET_AS_INPUT;
    
    LED_1 = LED_OFF;
    LED_2 = LED_OFF;
    
    
    HDC2080_initialize(DEVICE_ADDRESS, 400);
    
    HDC2080_cleaning_cycle (DEVICE_ADDRESS, 10);
    
    //Calibration value, if needed (You may use different values))
    HDC2080_set_humidity_offset (DEVICE_ADDRESS, HDC2080_CONF_HUM_ADJ_MINUS_25 + HDC2080_CONF_HUM_ADJ_PLUS_12_5 + 
                                HDC2080_CONF_HUM_ADJ_PLUS_3_1 + HDC2080_CONF_HUM_ADJ_PLUS_0_4);
    
    HDC2080_set_humidity_limit(DEVICE_ADDRESS, HDC2080_HUMIDITY_HIGH, HUMIDITY_LIMIT);
    
    //Comparator mode is used. If you use Level mode, to reset the interrupt bit you need to read back 
    //The status register, or the interrupt will remain set. 
    HDC2080_set_interrupt_modes (DEVICE_ADDRESS, HDC2080_INT_ENABLED + HDC2080_INT_ACTIVE_HIGH + HDC2080_INT_COMPARATOR_MODE);
    
    //Enable the Interrupt on the high temperature level
    HDC2080_set_interrupt_enable (DEVICE_ADDRESS, HDC2080_INT_HH_ENABLE);
    
    HDC2080_set_sampling_modes (DEVICE_ADDRESS, HDC2080_SAMPLING_EVERY_1s);
    
    //It is required to start the auto measure sequence
    HDC2080_trigger_new_measure (DEVICE_ADDRESS); 
    
    UART1_open (UART_BAUDRATE_19200);          
                        
    while (1){
        
        delay_ms (500);
        //Back space sent as clear monitor
        //RS232 Terminal must be set accordingly
        UART1_write_byte(8); 
       
        HDC2080_get_temperature (DEVICE_ADDRESS, &temperature); 
        LTlib_float_to_string (buffer, temperature,2);
        UART1_write_message ("Temperature : ");
        UART1_write_string(buffer);
        UART1_write_byte(13);
        
        HDC2080_get_humidity (DEVICE_ADDRESS, &humidity); 
        LTlib_float_to_string (buffer, humidity, 1);
        UART1_write_message ("Humidity : ");
        UART1_write_string(buffer);
        UART1_write_byte(13);
        
        HDC2080_get_device_ID (DEVICE_ADDRESS, &device_ID);
        
        if (device_ID == HDC2080_DEVICE_ID) {
            LED_2 = LED_ON;
        } else {
            LED_2 = LED_OFF;
        }

        if (HDC_INT == 0x01){
            LED_1 = 0x01;
        } else {
            LED_1 = 0x00;
        }        
        
    }
}  

