//******************************************************************************
// The software reads the Pressure, Humidity and Temperature. 
// All the data is sent out via UART. 
//
//
// Tested Platform: mini Controller Board PIC32
// Tested MCU: PIC32MX150F128D
// Tested Compiler: XC32 4.30
//******************************************************************************

#include "xc.h"

#define SYSTEM_CLOCK 32000000UL

#include "LTlib.h"

#include "HW_mini_Sensing_PIC_Board.h"

#include "LTlib_utilities.h"
#include "LTlib_utilities.c"

#include "module_IO.h"  
#include "module_IO.c" 

#include "module_UART.h"  
#include "module_UART.c" 

#include "module_I2C.h"
#include "module_I2C.c"

#include "LTlib_delay.h"
#include "LTlib_delay.c"

#include "BME280.h"
#include "BME280.c"

#define DEVICE_ADDRESS 0x76 //A0=GND

int main (void){

    uint8_t device_ID = 0x00;
    int32_t temperature = 0;
    uint32_t pressure = 0;
    uint32_t humidity = 0;
    
    uint8_t buffer[10];

    IO_set_all_ports_as_inputs ();
    delay_set_quartz(32);
    
    BME280_initialize (DEVICE_ADDRESS, 100);
        
    //Set LED as output
    LED_1_DIR = 0x00;
    LED_2_DIR = 0x00;
    
    LED_1 = LED_OFF;
    LED_2 = LED_OFF;
    
    UART1_open (UART_BAUDRATE_19200);          
                     
    while(1){        

               
        BME280_trigger_new_measure (DEVICE_ADDRESS);        
        while (BME280_is_conversion_running(DEVICE_ADDRESS));

        delay_ms (500);
        //Back space sent as clear monitor
        //RS232 Terminal must be set accordingly
        UART1_write_byte(8); 
        
        //**********************************
        //         Temperature
        //**********************************
        UART1_write_message("Temperature: ");
        BME280_get_temperature (DEVICE_ADDRESS, &temperature);
        //Write integer part only
        LTlib_float_to_string (buffer, ((float)temperature / 100),2);
        UART1_write_string (buffer);
        UART1_write_message(" ");
        UART1_write_message("C");
        UART1_write_byte(13);
        UART1_write_byte(13);
        
        //**********************************
        //         Pressure
        //**********************************
        UART1_write_message("Pressure: ");
        BME280_get_pressure (DEVICE_ADDRESS, &pressure);        
        //The LCD shows kPa value
        LTlib_float_to_string (buffer, ((float)pressure / 1000),2);
        UART1_write_string (buffer);
        UART1_write_message(" kPa");
        UART1_write_byte(13);  
        UART1_write_byte(13);
          
        
        //**********************************
        //         Humidity
        //**********************************
        UART1_write_message("Humidity: ");
        BME280_get_humidity (DEVICE_ADDRESS, &humidity);
        
        LTlib_float_to_string (buffer, ((float)humidity / 1024),2);
        UART1_write_string (buffer);
        UART1_write_message(" ");
        UART1_write_message("%");
        UART1_write_byte(13);
        UART1_write_byte(13);
        
        
        //**********************************
        //         Device Info
        //**********************************
        UART1_write_message("Device : ");
        BME280_get_device_ID (DEVICE_ADDRESS, &device_ID);
        
        if (device_ID == BME280_DEVICE_ID) {
            UART1_write_message("BME280");
            LED_2 = LED_ON;
        } else {
            UART1_write_message("Unknown");
            LED_2 = LED_OFF;
        }

        LED_1 ^= 0x01;
    }
        
}   

