//******************************************************************************
// The software reads the angular speed out of the LSM6DSM sensor
// and writes it to the GLCD.
// The GLCD must be connected as specified in the library included above.
// The LSM6DSM must be connected to the I2C Module 1 of the MCU.  
// The LSM6DSM address bit is connected to GND (Device address: 0x6A)
//
//
// Tested Platform: mini Controller Board PIC32
// Tested MCU: PIC32MX150F128D
// Tested Compiler: XC32 4.30
//******************************************************************************

#include <xc.h>

#define SYSTEM_CLOCK 32000000UL
#include "LTlib.h"

#include "HW_mini_Sensing_PIC_Board.h"

#include "LTlib_delay.h"
#include "LTlib_delay.c"

#include "LTlib_utilities.h"
#include "LTlib_utilities.c"

#include "module_IO.h"
#include "module_IO.c"

#include "module_I2C.h"
#include "module_I2C.c"

#include "LSM6DSM.h"
#include "LSM6DSM.c"

#include "module_UART.h"  
#include "module_UART.c" 

#define DEVICE_ADDRESS 0x6A

void main (void) {
    
    uint8_t data = 0;
    uint8_t hex_string[6];
    uint8_t status;
    
    uint8_t buffer[10];
    
    float dps_X = 0;
    float dps_Y = 0;
    float dps_Z = 0;
    
    IO_set_all_ports_as_inputs();
    
    LED_2_DIR  = SET_AS_OUTPUT;
    
    delay_set_quartz(32);
    
    UART1_open (UART_BAUDRATE_19200);
    
    LSM6DSM_initialize (DEVICE_ADDRESS, 400);
    LSM6DSM_set_full_scale (DEVICE_ADDRESS,LSM6DSM_GYROSCOPE, LSM6DSM_GYRO_FULLSCALE_2000_dps);
    LSM6DSM_set_sampling_frequency (DEVICE_ADDRESS, LSM6DSM_GYROSCOPE, LSM6DSM_GYRO_SAMPLING_416_HZ);
    
    LSM6DSM_get_device_ID (DEVICE_ADDRESS, &data); 
    LTlib_Hex8_to_string (hex_string, data);
            
    while(1){   
        
        delay_ms (500);
        //Back space sent as clear monitor
        //RS232 Terminal must be set accordingly
        UART1_write_byte(8); 
        
        UART1_write_message("Device ID: 0x");
        UART1_write_string (hex_string);
        UART1_write_byte(13);
        UART1_write_byte(13);
        
        LSM6DSM_get_interrupt_status (DEVICE_ADDRESS, &status);
        
        if (status & LSM6DSM_STATUS_GDA){

            LSM6DSM_get_angular_speed(DEVICE_ADDRESS, &dps_X, &dps_Y, &dps_Z);
            LTlib_float_to_string (buffer, dps_X, 2);
            UART1_write_message("dps X: ");
            UART1_write_string(buffer);
            UART1_write_byte(13);
            UART1_write_byte(13);

            LTlib_float_to_string (buffer, dps_Y, 2);
            UART1_write_message("dps Y: ");
            UART1_write_string(buffer);
            UART1_write_byte(13);
            UART1_write_byte(13);

            LTlib_float_to_string (buffer, dps_Z, 2);
            UART1_write_message("dps Z: ");
            UART1_write_string(buffer);
            UART1_write_byte(13);
            UART1_write_byte(13); 
        }else {
            UART1_write_message("No Acc. data ready...");
            UART1_write_byte(13);
            UART1_write_byte(13);
        }
               
        
        if (data == LSM6DSM_DEVICE_ID){
            LED_2 ^= 0x01;
        } else {
            LED_2 = 0x01;
        }
          
    }
}

